@@ -3,6 +3,8 @@
 #' Get a summary of all your accounts, web properties and views your authenticated user can see.
 #'
 #' @seealso https://developers.google.com/analytics/devguides/config/mgmt/v3/mgmtReference/management/accountSummaries/list
+#' 
+#' @param type Whether to get account summary from universal analytics of GA4 (App_Web) properties
 #'
 #' @return a dataframe of all account, webproperty and view data
 #' @importFrom googleAuthR gar_api_generator
@@ -12,7 +14,7 @@
 #' 
 #' @description 
 #' 
-#' This is the recommended way to get all your account details for your user, including the web property and View IDs.  The \code{$viewId} column contains the ID you need for the data fetching functions such as \link{google_analytics}.
+#' This is the recommended way to get all your account details for your user, including the web property and View IDs.  The `$viewId` column contains the ID you need for the data fetching functions such as [google_analytics].
 #' 
 #' @examples 
 #' 
@@ -22,8 +24,16 @@
 #' ga_auth()
 #' al <- ga_account_list()
 #' al$viewId
+#' 
+#' ## get account summary of GA4 properties
+#' ga_account_list("ga4")
 #' }
-ga_account_list <- function(){
+ga_account_list <- function(type = c("universal","ga4", "data")){
+  type <- match.arg(type)
+  
+  if(type %in% c("ga4","data")){
+    return(ga_admin_account_summary())
+  }
   
   url <- "https://www.googleapis.com/analytics/v3/management/accountSummaries"
   acc_sum <- gar_api_generator(url,
@@ -39,7 +49,7 @@ ga_account_list <- function(){
 #' List account metadata
 #' 
 #' This gets the meta data associated with the accounts you have access to with your user.  
-#' If you want all information such as web properties and viewIds, use \link{ga_account_list} instead.
+#' If you want all information such as web properties and viewIds, use [ga_account_list] instead.
 #'
 #' @importFrom googleAuthR gar_api_generator
 #' @family account structure functions
@@ -48,7 +58,7 @@ ga_account_list <- function(){
 #' 
 #'   This gets a list of account meta data, that can be used in other management API functions.
 #'   
-#' @return A \code{data.frame} with accountid, name, an R datetime object (\code{POSIXct}) when the account was created and last updated, and the effective permissions your user has for those accounts. 
+#' @return A `data.frame` with accountid, name, an R datetime object (`POSIXct`) when the account was created and last updated, and the effective permissions your user has for those accounts. 
 #' 
 #' @export
 #' @examples 
@@ -86,4 +96,4 @@ parse_ga_accounts <- function(x){
   
   attr(o, "nextLink") <- x$nextLink
   o
-}
\ No newline at end of file
+}
